summaryrefslogtreecommitdiffstats
path: root/libkpgp/kpgpui.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkpgp/kpgpui.h')
-rw-r--r--libkpgp/kpgpui.h126
1 files changed, 63 insertions, 63 deletions
diff --git a/libkpgp/kpgpui.h b/libkpgp/kpgpui.h
index eab9a53e..48e6fecd 100644
--- a/libkpgp/kpgpui.h
+++ b/libkpgp/kpgpui.h
@@ -20,12 +20,12 @@
#define KPGPUI_H
#include <kdialogbase.h> // base class of all dialogs here
-#include <qwidget.h> // base class of Config
-#include <qcheckbox.h> // used in inlined methods
+#include <tqwidget.h> // base class of Config
+#include <tqcheckbox.h> // used in inlined methods
#include <kdebug.h> // used in inlined methods
-#include <qcstring.h> // used in return-by-value
-#include <qstring.h> // is a member in KeyRequester
-#include <qvaluevector.h> // used in KeyApprovalDialog
+#include <tqcstring.h> // used in return-by-value
+#include <tqstring.h> // is a member in KeyRequester
+#include <tqvaluevector.h> // used in KeyApprovalDialog
#include "kpgp.h"
@@ -57,8 +57,8 @@ class KDE_EXPORT PassphraseDialog : public KDialogBase
Q_OBJECT
public:
- PassphraseDialog( QWidget *parent=0, const QString &caption=QString::null,
- bool modal=true, const QString &keyID=QString::null);
+ PassphraseDialog( TQWidget *parent=0, const TQString &caption=TQString::null,
+ bool modal=true, const TQString &keyID=TQString::null);
virtual ~PassphraseDialog();
const char * passphrase();
@@ -77,23 +77,23 @@ class KDE_EXPORT Config : public QWidget
Q_OBJECT
public:
- Config(QWidget *parent = 0, const char *name = 0, bool encrypt =true);
+ Config(TQWidget *parent = 0, const char *name = 0, bool encrypt =true);
virtual ~Config();
virtual void setValues();
virtual void applySettings();
- QGroupBox* optionsGroupBox() { return mpOptionsGroupBox; };
+ TQGroupBox* optionsGroupBox() { return mpOptionsGroupBox; };
signals:
void changed();
protected:
Module *pgp;
- QCheckBox *storePass;
- QCheckBox *encToSelf;
- QCheckBox *showCipherText;
- QCheckBox *showKeyApprovalDlg;
- QComboBox *toolCombo;
- QGroupBox* mpOptionsGroupBox;
+ TQCheckBox *storePass;
+ TQCheckBox *encToSelf;
+ TQCheckBox *showCipherText;
+ TQCheckBox *showKeyApprovalDlg;
+ TQComboBox *toolCombo;
+ TQGroupBox* mpOptionsGroupBox;
};
@@ -112,13 +112,13 @@ class KDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
/** allowedKeys: see kpgp.h
*/
KeySelectionDialog( const KeyList& keyList,
- const QString& title,
- const QString& text = QString::null,
+ const TQString& title,
+ const TQString& text = TQString::null,
const KeyIDList& keyIds = KeyIDList(),
const bool rememberChoice = false,
const unsigned int allowedKeys = AllKeys,
const bool extendedSelection = false,
- QWidget *parent=0, const char *name=0,
+ TQWidget *parent=0, const char *name=0,
bool modal=true );
virtual ~KeySelectionDialog();
@@ -139,37 +139,37 @@ class KDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
protected slots:
virtual void slotRereadKeys();
- virtual void slotSelectionChanged( QListViewItem* );
+ virtual void slotSelectionChanged( TQListViewItem* );
virtual void slotSelectionChanged();
- virtual void slotCheckSelection( QListViewItem* = 0 );
- virtual void slotRMB( QListViewItem*, const QPoint&, int );
+ virtual void slotCheckSelection( TQListViewItem* = 0 );
+ virtual void slotRMB( TQListViewItem*, const TQPoint&, int );
virtual void slotRecheckKey();
virtual void slotOk();
virtual void slotCancel();
- virtual void slotSearch( const QString & text );
+ virtual void slotSearch( const TQString & text );
virtual void slotFilter();
private:
- void filterByKeyID( const QString & keyID );
- void filterByKeyIDOrUID( const QString & keyID );
- void filterByUID( const QString & uid );
+ void filterByKeyID( const TQString & keyID );
+ void filterByKeyIDOrUID( const TQString & keyID );
+ void filterByUID( const TQString & uid );
void showAllItems();
- bool anyChildMatches( const QListViewItem * item, QRegExp & rx ) const;
+ bool anyChildMatches( const TQListViewItem * item, TQRegExp & rx ) const;
void initKeylist( const KeyList& keyList, const KeyIDList& keyIds );
- QString keyInfo( const Kpgp::Key* ) const;
+ TQString keyInfo( const Kpgp::Key* ) const;
- QString beautifyFingerprint( const QCString& ) const;
+ TQString beautifyFingerprint( const TQCString& ) const;
- // Returns the key ID of the key the given QListViewItem belongs to
- KeyID getKeyId( const QListViewItem* ) const;
+ // Returns the key ID of the key the given TQListViewItem belongs to
+ KeyID getKeyId( const TQListViewItem* ) const;
// Returns: -1 = unusable, 0 = unknown, 1 = valid, but untrusted, 2 = trusted
int keyValidity( const Kpgp::Key* ) const;
- // Updates the given QListViewItem with the data of the given key
- void updateKeyInfo( const Kpgp::Key*, QListViewItem* ) const;
+ // Updates the given TQListViewItem with the data of the given key
+ void updateKeyInfo( const Kpgp::Key*, TQListViewItem* ) const;
/** Checks if choosing the given key is allowed
Returns:
@@ -178,22 +178,22 @@ class KDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
or not,
1 = key can be chosen
*/
- int keyAdmissibility( QListViewItem*,
+ int keyAdmissibility( TQListViewItem*,
TrustCheckMode = NoExpensiveTrustCheck ) const;
// Perform expensive trust checks for the given keys
- bool checkKeys( const QValueList<QListViewItem*>& ) const;
+ bool checkKeys( const TQValueList<TQListViewItem*>& ) const;
private:
KListView *mListView;
- QCheckBox *mRememberCB;
- QPixmap *mKeyGoodPix, *mKeyBadPix, *mKeyUnknownPix, *mKeyValidPix;
+ TQCheckBox *mRememberCB;
+ TQPixmap *mKeyGoodPix, *mKeyBadPix, *mKeyUnknownPix, *mKeyValidPix;
KeyIDList mKeyIds;
unsigned int mAllowedKeys;
- QTimer* mCheckSelectionTimer;
- QTimer* mStartSearchTimer;
- QString mSearchText;
- QListViewItem* mCurrentContextMenuItem;
+ TQTimer* mCheckSelectionTimer;
+ TQTimer* mStartSearchTimer;
+ TQString mSearchText;
+ TQListViewItem* mCurrentContextMenuItem;
static const int sCheckSelectionDelay;
};
@@ -203,18 +203,18 @@ class KDE_EXPORT KeyRequester: public QWidget
Q_OBJECT
public:
- KeyRequester( QWidget * parent=0, bool multipleKeys=false,
+ KeyRequester( TQWidget * parent=0, bool multipleKeys=false,
unsigned int allowedKeys=AllKeys, const char * name=0 );
virtual ~KeyRequester();
KeyIDList keyIDs() const;
void setKeyIDs( const KeyIDList & keyIDs );
- QPushButton * eraseButton() const { return mEraseButton; }
- QPushButton * dialogButton() const { return mDialogButton; }
+ TQPushButton * eraseButton() const { return mEraseButton; }
+ TQPushButton * dialogButton() const { return mDialogButton; }
- void setDialogCaption( const QString & caption );
- void setDialogMessage( const QString & message );
+ void setDialogCaption( const TQString & caption );
+ void setDialogMessage( const TQString & message );
bool isMultipleKeysEnabled() const;
void setMultipleKeysEnabled( bool enable );
@@ -227,10 +227,10 @@ protected:
virtual KeyIDList keyRequestHook( Module * pgp ) const = 0;
protected:
- QLabel * mLabel;
- QPushButton * mEraseButton;
- QPushButton * mDialogButton;
- QString mDialogCaption, mDialogMessage;
+ TQLabel * mLabel;
+ TQPushButton * mEraseButton;
+ TQPushButton * mDialogButton;
+ TQString mDialogCaption, mDialogMessage;
bool mMulti;
int mAllowedKeys;
KeyIDList mKeys;
@@ -253,7 +253,7 @@ protected:
class KDE_EXPORT PublicKeyRequester : public KeyRequester {
Q_OBJECT
public:
- PublicKeyRequester( QWidget * parent=0, bool multipleKeys=false,
+ PublicKeyRequester( TQWidget * parent=0, bool multipleKeys=false,
unsigned int allowedKeys=PublicKeys, const char * name=0 );
virtual ~PublicKeyRequester();
@@ -272,7 +272,7 @@ protected:
class KDE_EXPORT SecretKeyRequester : public KeyRequester {
Q_OBJECT
public:
- SecretKeyRequester( QWidget * parent=0, bool multipleKeys=false,
+ SecretKeyRequester( TQWidget * parent=0, bool multipleKeys=false,
unsigned int allowedKeys=SecretKeys, const char * name=0 );
virtual ~SecretKeyRequester();
@@ -294,14 +294,14 @@ class KDE_EXPORT KeyApprovalDialog: public KDialogBase
Q_OBJECT
public:
- KeyApprovalDialog( const QStringList&,
- const QValueVector<KeyIDList>&,
+ KeyApprovalDialog( const TQStringList&,
+ const TQValueVector<KeyIDList>&,
const int allowedKeys,
- QWidget *parent = 0, const char *name = 0,
+ TQWidget *parent = 0, const char *name = 0,
bool modal = true );
virtual ~KeyApprovalDialog() {};
- QValueVector<KeyIDList> keys() const { return mKeys; };
+ TQValueVector<KeyIDList> keys() const { return mKeys; };
bool preferencesChanged() const { return mPrefsChanged; }
@@ -312,14 +312,14 @@ class KDE_EXPORT KeyApprovalDialog: public KDialogBase
virtual void slotCancel();
private:
- QValueVector<KeyIDList> mKeys;
+ TQValueVector<KeyIDList> mKeys;
int mAllowedKeys;
int mEncryptToSelf;
bool mPrefsChanged;
- QPtrVector<QLabel> mAddressLabels;
- QPtrVector<QLabel> mKeyIdsLabels;
- //QPtrVector<QListBox> mKeyIdListBoxes;
- QPtrVector<QComboBox> mEncrPrefCombos;
+ TQPtrVector<TQLabel> mAddressLabels;
+ TQPtrVector<TQLabel> mKeyIdsLabels;
+ //TQPtrVector<TQListBox> mKeyIdListBoxes;
+ TQPtrVector<TQComboBox> mEncrPrefCombos;
};
@@ -329,13 +329,13 @@ class KDE_EXPORT CipherTextDialog: public KDialogBase
Q_OBJECT
public:
- CipherTextDialog( const QCString & text, const QCString & charset=0,
- QWidget *parent=0, const char *name=0, bool modal=true );
+ CipherTextDialog( const TQCString & text, const TQCString & charset=0,
+ TQWidget *parent=0, const char *name=0, bool modal=true );
virtual ~CipherTextDialog() {};
private:
void setMinimumSize();
- QMultiLineEdit *mEditBox;
+ TQMultiLineEdit *mEditBox;
};
} // namespace Kpgp